@@ -367,10 +367,20 @@ class AuthProgs(object):  # pylint: disable-msg=R0902
     def dump_config(self):
         """Pretty print the configuration dict to stdout."""
         yaml_content = self.get_merged_config()
+        print(
+            'Configuration Source:\n\t{}\n'.format(
+                yaml_content.read().replace('\n', '\n\t')
+            )
+        )
         yaml_content.close()
 
         try:
             self.load()
+            print(
+                'Effective Configuration\n\t{}\n'.format(
+                    pretty(self.yamldocs).replace('\n', '\n\t')
+                )
+            )
         except ConfigError:
             sys.stderr.write(
                 'config parse error. try running with --logfile=/dev/tty\n'
@@ -671,15 +681,14 @@ def main():  # pylint: disable-msg=R0912,R0915
         metavar='FILE',
     )
     group.add_argument(
-        '--version',
-        action='store_true',
-        help='Show version and exit.'
+        '--version', action='store_true', help='Show version and exit.'
     )
 
     args = parser.parse_args()
 
     if args.version:
         from . import __version__
+
         print(__version__)
         sys.exit()
 
